*************
Python module
*************

Overview
========

BibTeX
------

.. autosummary::

    GooseBib.bibtex.clean
    GooseBib.bibtex.select
    GooseBib.bibtex.unique
    GooseBib.bibtex.get_identifiers
    GooseBib.bibtex.format_journal_arxiv
    GooseBib.bibtex.dbsearch_arxiv

Automatic formatting
--------------------

.. autosummary::

    GooseBib.reformat.remove_wrapping_braces
    GooseBib.reformat.abbreviate_firstname
    GooseBib.reformat.name2key

Automatic information extraction
--------------------------------

.. autosummary::

    GooseBib.recognise.doi
    GooseBib.recognise.arxivid

Official journal names
----------------------

.. autosummary::

    GooseBib.journals.read
    GooseBib.journals.load
    GooseBib.journals.get_configdir
    GooseBib.journals.update_default
    GooseBib.journals.generate_default
    GooseBib.journals.download_from_jabref
    GooseBib.journals.dump
    GooseBib.journals.Journal
    GooseBib.journals.JournalList

GooseBib.bibtex
===============

.. automodule:: GooseBib.bibtex
  :members:

GooseBib.reformat
=================

.. automodule:: GooseBib.reformat
  :members:

GooseBib.recognise
==================

.. automodule:: GooseBib.recognise
  :members:

GooseBib.journals
=================

.. automodule:: GooseBib.journals
  :members:
